@@ -23,7 +23,12 @@ from pdfminer.layout import LAParams
 from pdfminer.converter import PDFPageAggregator
 import pdfminer
 from io import StringIO
-from IQDMPDF.utilities import get_sorted_indices, is_in_tol, bbox_to_pos
+from IQDMPDF.utilities import (
+    get_sorted_indices,
+    is_in_tol,
+    bbox_to_pos,
+    is_numeric,
+)
 
 # Search tolerance for get_block_data
 TOLERANCE = 10
@@ -96,7 +101,14 @@ class CustomPDFReader:
         return self.__str__()
 
     def get_block_data(
-        self, page, pos, tol=TOLERANCE, text_cleaner=None, mode="bottom-left"
+        self,
+        page,
+        pos,
+        tol=TOLERANCE,
+        text_cleaner=None,
+        numeric=None,
+        ignored=None,
+        mode="bottom-left",
     ):
         """Use PDFPageParser.get_block_data for the provided page
 
@@ -112,6 +124,13 @@ class CustomPDFReader:
             2nd is y_tolerance
         text_cleaner : callable, optional
             A function called on each text element (e.g., remove leading ':')
+        numeric : bool, optional
+            If true, only return value if it is numeric. If false, only return
+            value if it is not numeric. Leave as None to ignore this feature.
+        ignored : list, optional
+            Optionally provide a list of strings that should be ignored. If
+            the value of the block data is in this list, the value will become
+            an empty string instead
         mode : str, optional
             Options are combinations of top/center/bottom and
             right/center/left, e.g., 'top-right', 'center-right'.
@@ -124,11 +143,16 @@ class CustomPDFReader:
             All text data that meet the input constraints
         """
         return self.page[page].get_block_data(
-            pos, tol, text_cleaner=text_cleaner, mode=mode
+            pos,
+            tol,
+            text_cleaner=text_cleaner,
+            numeric=numeric,
+            ignored=ignored,
+            mode=mode,
         )
 
     def convert_pdf_to_text(self):
-        """ "Extract text and coordinates from a PDF"""
+        """Extract text and coordinates from a PDF"""
 
         # Open a PDF file.
         fp = open(self.file_path, "rb")
@@ -186,7 +210,7 @@ class CustomPDFReader:
         Returns
         ----------
         dict
-            Keys are {"page": [int], "bbox": list}
+             "page"->int and "bbox"->[x0, y0, x1, y1]
 
         """
         for p, page in enumerate(self.page):
@@ -287,7 +311,15 @@ class PDFPageParser:
         for key in list(self.data):
             self.data[key] = [self.data[key][i] for i in sorted_indices]
 
-    def get_block_data(self, pos, tol, text_cleaner=None, mode="bottom-left"):
+    def get_block_data(
+        self,
+        pos,
+        tol,
+        text_cleaner=None,
+        numeric=None,
+        ignored=None,
+        mode="bottom-left",
+    ):
         """Get the text block data by x,y coordinates
 
         Parameters
@@ -300,6 +332,13 @@ class PDFPageParser:
             2nd is y_tolerance
         text_cleaner : callable, optional
             A function called on each text element (e.g., remove leading ':')
+        numeric : bool, optional
+            If true, only return value if it is numeric. If false, only return
+            value if it is not numeric. Leave as None to ignore this feature.
+        ignored : list, optional
+            Optionally provide a list of strings that should be ignored. If
+            the value of the block data is in this list, the value will become
+            an empty string instead
         mode : str, optional
             Options are combinations of top/center/bottom and
             right/center/left, e.g., 'top-right', 'center-right'.
@@ -325,6 +364,17 @@ class PDFPageParser:
                     if text_cleaner is None
                     else text_cleaner(data)
                 )
+
+                if ignored is not None and data_clean in ignored:
+                    data_clean = ""
+
+                if data_clean and numeric is not None:
+                    data_is_numeric = is_numeric(data_clean)
+                    if (numeric and not data_is_numeric) or (
+                        not numeric and data_is_numeric
+                    ):
+                        data_clean = ""
+
                 if data_clean:
                     block_data.append(data_clean)
         return block_data
