@@ -455,5 +455,34 @@ TEST_DATA = {
                 "Notes": "bst2",
             },
         },
+        "NorthwesternArcCheck3": {
+            "path": join(
+                DIRECTORIES["SNCPATIENT2020_EXAMPLES"],
+                "Northwestern_Memorial",
+                "ArcCheck_Example_3.pdf",
+            ),
+            "data": {
+                "Patient Name": "H M",
+                "Patient ID": "00000000003",
+                "QA Date": "12 Jan 2021 09:36:50",
+                "Plan Date": "12 Jan 2021 06:59:10",
+                "Plan Name": "Pelvis 3-6",
+                "Plan ID": "",
+                "Verified Plan UID": "",
+                "Total MU": "2196.4",
+                "Comparison Type": "Absolute Dose Comparison (GC/Gamma using 3D Mode)",
+                "Threshold (%)": "20.0",
+                "Use Global (%)": "No",
+                "Difference (%)": "2.0",
+                "Meas Uncertainty": "No",
+                "Distance (mm)": "2.0",
+                "Summary Type": "Summary (GC Analysis)",
+                "Pass (%)": "91.8",
+                "Pass": "1024",
+                "Fail": "91",
+                "Total Points": "1115",
+                "Notes": "6X SLF",
+            },
+        },
     },
 }
